@@ -12,26 +12,28 @@
 ##############################################################################
 """ Cookie Crumbler: Enable cookies for non-cookie user folders.
 
-$Id: CookieCrumbler.py 110655 2010-04-08 15:38:57Z tseaver $
+$Id: CookieCrumbler.py 110577 2010-04-07 06:33:17Z jens $
 """
 
 from base64 import encodestring, decodestring
 from urllib import quote, unquote
 
-from Acquisition import aq_inner, aq_parent
-from DateTime import DateTime
-from AccessControl import ClassSecurityInfo, Permissions
-from ZPublisher import BeforeTraverse
-import Globals
-from Globals import HTMLFile
-from ZPublisher.HTTPRequest import HTTPRequest
+from AccessControl.Permissions import view_management_screens
+from AccessControl.SecurityInfo import ClassSecurityInfo
+from Acquisition import aq_inner
+from Acquisition import aq_parent
+from App.class_init import InitializeClass
+from App.special_dtml import HTMLFile
+from DateTime.DateTime import DateTime
 from OFS.Folder import Folder
-from zExceptions import Redirect
-from zope.interface import implements
-from zope.app.container.interfaces import IObjectMovedEvent
 from OFS.interfaces import IObjectWillBeMovedEvent
+from zExceptions import Redirect
+from zope.container.interfaces import IObjectMovedEvent
+from zope.interface import implements
+from ZPublisher import BeforeTraverse
+from ZPublisher.HTTPRequest import HTTPRequest
 
-from interfaces import ICookieCrumbler
+from Products.CMFCore.interfaces import ICookieCrumbler
 
 
 # Constants.
@@ -40,7 +42,7 @@ ATTEMPT_LOGIN = 1      # Attempt to log in
 ATTEMPT_RESUME = 2     # Attempt to resume session
 
 ModifyCookieCrumblers = 'Modify Cookie Crumblers'
-ViewManagementScreens = Permissions.view_management_screens
+ViewManagementScreens = view_management_screens
 
 
 class CookieCrumblerDisabled(Exception):
@@ -342,11 +344,7 @@ class CookieCrumbler(Folder):
             if page is not None:
                 came_from = req.get('came_from', None)
                 if came_from is None:
-                    came_from = req.get('VIRTUAL_URL', None)
-                    if came_from is None:
-                        came_from = '%s%s%s' % ( req['SERVER_URL'].strip(),
-                                                 req['SCRIPT_NAME'].strip(),
-                                                 req['PATH_INFO'].strip() )
+                    came_from = req.get('ACTUAL_URL')
                     query = req.get('QUERY_STRING')
                     if query:
                         # Include the query string in came_from
@@ -391,7 +389,7 @@ class CookieCrumbler(Folder):
                 return p.get('label', id)
         return id
 
-Globals.InitializeClass(CookieCrumbler)
+InitializeClass(CookieCrumbler)
 
 
 def handleCookieCrumblerEvent(ob, event):
