@@ -12,7 +12,7 @@
 ##############################################################################
 """ Unit tests for CachingPolicyManager module.
 
-$Id: test_CachingPolicyManager.py 110655 2010-04-08 15:38:57Z tseaver $
+$Id: test_CachingPolicyManager.py 110577 2010-04-07 06:33:17Z jens $
 """
 
 import unittest
@@ -27,6 +27,7 @@ from Acquisition import Implicit
 from App.Common import rfc1123_date
 from DateTime.DateTime import DateTime
 from OFS.Cache import Cacheable
+from zope.interface.verify import verifyClass
 
 from Products.CMFCore.FSDTMLMethod import FSDTMLMethod
 from Products.CMFCore.FSPageTemplate import FSPageTemplate
@@ -105,8 +106,7 @@ class CachingPolicyTests(unittest.TestCase):
     def setUp(self):
         self._epoch = DateTime(0)
 
-    def test_z3interfaces(self):
-        from zope.interface.verify import verifyClass
+    def test_interfaces(self):
         from Products.CMFCore.CachingPolicyManager import CachingPolicy
         from Products.CMFCore.interfaces import ICachingPolicy
 
@@ -438,16 +438,7 @@ class CachingPolicyManagerTests(unittest.TestCase):
     def assertEqualDelta( self, lhs, rhs, delta ):
         self.failUnless( abs( lhs - rhs ) <= delta )
 
-    def test_z2interfaces(self):
-        from Interface.Verify import verifyClass
-        from Products.CMFCore.CachingPolicyManager import CachingPolicyManager
-        from Products.CMFCore.interfaces.CachingPolicyManager \
-                import CachingPolicyManager as ICachingPolicyManager
-
-        verifyClass(ICachingPolicyManager, CachingPolicyManager)
-
-    def test_z3interfaces(self):
-        from zope.interface.verify import verifyClass
+    def test_interfaces(self):
         from Products.CMFCore.CachingPolicyManager import CachingPolicyManager
         from Products.CMFCore.interfaces import ICachingPolicyManager
 
